==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/CodeGeneratingComponentRendererModuleEmitter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, typeCast, markType } from "./type";
import { CodeGeneratingCodeWriter } from "./CodeGeneratingCodeWriter";
import { CodeGeneratingImportManager } from "./CodeGeneratingImportManager";
import { JsonDictionaryArray } from "./JsonDictionaryArray";
import { JsonDictionaryValue } from "./JsonDictionaryValue";
/**
 * @hidden
 */
var CodeGeneratingComponentRendererModuleEmitter = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CodeGeneratingComponentRendererModuleEmitter, _super);
    function CodeGeneratingComponentRendererModuleEmitter(a, b) {
        var _this = _super.call(this) || this;
        _this.j = null;
        _this.i = null;
        _this.b = null;
        _this.f = new CodeGeneratingImportManager();
        _this.e = new CodeGeneratingImportManager();
        _this.a = null;
        _this.j = a;
        _this.i = b;
        _this.b = new CodeGeneratingCodeWriter(_this.j);
        _this.a = new CodeGeneratingCodeWriter(_this.j);
        return _this;
    }
    Object.defineProperty(CodeGeneratingComponentRendererModuleEmitter.prototype, "d", {
        get: function () {
            return this.b;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CodeGeneratingComponentRendererModuleEmitter.prototype, "h", {
        get: function () {
            return this.f;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CodeGeneratingComponentRendererModuleEmitter.prototype, "g", {
        get: function () {
            return this.e;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CodeGeneratingComponentRendererModuleEmitter.prototype, "c", {
        get: function () {
            return this.a;
        },
        enumerable: true,
        configurable: true
    });
    CodeGeneratingComponentRendererModuleEmitter.prototype.l = function (a) {
        this.n();
        if (typeCast(JsonDictionaryArray.$, a) !== null) {
            var b = a;
            for (var c = 0; c < b.items.length; c++) {
                var d = b.items[c];
                if (typeCast(JsonDictionaryValue.$, d) !== null) {
                    var e = d;
                    if (e != null) {
                        var f = e.value.toString();
                        this.k(f);
                    }
                }
            }
        }
        this.m();
        this.i.addImportResult("modulesImports", this.h);
        this.i.addContainerResult("modulesRegister", this.d.toString());
        this.i.addImportResult("descriptionImports", this.g);
        this.i.addContainerResult("descriptionRegister", this.c.toString());
    };
    CodeGeneratingComponentRendererModuleEmitter.prototype.m = function () {
    };
    CodeGeneratingComponentRendererModuleEmitter.prototype.k = function (a) {
    };
    CodeGeneratingComponentRendererModuleEmitter.prototype.n = function () {
    };
    CodeGeneratingComponentRendererModuleEmitter.$t = markType(CodeGeneratingComponentRendererModuleEmitter, 'CodeGeneratingComponentRendererModuleEmitter');
    return CodeGeneratingComponentRendererModuleEmitter;
}(Base));
export { CodeGeneratingComponentRendererModuleEmitter };

==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/CodeGeneratingComponentRendererModuleEmitter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, typeCast, markType } from "./type";
import { CodeGeneratingCodeWriter } from "./CodeGeneratingCodeWriter";
import { CodeGeneratingImportManager } from "./CodeGeneratingImportManager";
import { JsonDictionaryArray } from "./JsonDictionaryArray";
import { JsonDictionaryValue } from "./JsonDictionaryValue";
/**
 * @hidden
 */
var CodeGeneratingComponentRendererModuleEmitter = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CodeGeneratingComponentRendererModuleEmitter, _super);
    function CodeGeneratingComponentRendererModuleEmitter(a, b) {
        var _this = _super.call(this) || this;
        _this.k = null;
        _this.i = null;
        _this.b = null;
        _this.f = new CodeGeneratingImportManager();
        _this.e = new CodeGeneratingImportManager();
        _this.a = null;
        _this.k = a;
        _this.i = b;
        _this.b = new CodeGeneratingCodeWriter(_this.k);
        _this.a = new CodeGeneratingCodeWriter(_this.k);
        return _this;
    }
    Object.defineProperty(CodeGeneratingComponentRendererModuleEmitter.prototype, "j", {
        get: function () {
            return this.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CodeGeneratingComponentRendererModuleEmitter.prototype, "d", {
        get: function () {
            return this.b;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CodeGeneratingComponentRendererModuleEmitter.prototype, "h", {
        get: function () {
            return this.f;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CodeGeneratingComponentRendererModuleEmitter.prototype, "g", {
        get: function () {
            return this.e;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CodeGeneratingComponentRendererModuleEmitter.prototype, "c", {
        get: function () {
            return this.a;
        },
        enumerable: true,
        configurable: true
    });
    CodeGeneratingComponentRendererModuleEmitter.prototype.m = function (a) {
        this.o();
        if (typeCast(JsonDictionaryArray.$, a) !== null) {
            var b = a;
            for (var c = 0; c < b.items.length; c++) {
                var d = b.items[c];
                if (typeCast(JsonDictionaryValue.$, d) !== null) {
                    var e = d;
                    if (e != null) {
                        var f = e.value.toString();
                        this.l(f);
                    }
                }
            }
        }
        this.n();
        this.i.addImportResult("modulesImports", this.h);
        this.i.addContainerResult("modulesRegister", this.d.toString());
        this.i.addImportResult("descriptionImports", this.g);
        this.i.addContainerResult("descriptionRegister", this.c.toString());
    };
    CodeGeneratingComponentRendererModuleEmitter.prototype.n = function () {
    };
    CodeGeneratingComponentRendererModuleEmitter.prototype.l = function (a) {
    };
    CodeGeneratingComponentRendererModuleEmitter.prototype.o = function () {
    };
    CodeGeneratingComponentRendererModuleEmitter.$t = markType(CodeGeneratingComponentRendererModuleEmitter, 'CodeGeneratingComponentRendererModuleEmitter');
    return CodeGeneratingComponentRendererModuleEmitter;
}(Base));
export { CodeGeneratingComponentRendererModuleEmitter };
